make_phynotate generates a standalone {shiny} app with one phylogeny and widgets for customizing its appearence. This is a wrapper around phynotate::main_ui/server to simplify usage when a the main module is called as a standalone app. See ?draw_server and ?main_server for an for info on how to include the modules in an existing app.

make_phynotate(
  phylogeny = NULL,
  draw_modules = "LPTB",
  annotation_module = FALSE
)

Arguments

phylogeny

an object of class phylo to display. Very large phylogenies typically will be dificult to display legibly.

draw_modules

character string specifying the customizing widgets (shiny modules) to include. The default is "LPBT" which stands for Layout, Plot area, Branches, and Tips. Changing the content and order can be achieved by changing the string, e.g., "LP" will only allow customization of the plot layout and size, whereas "BTL" will show widgets for branches, tips, and layout in that order.

annotation_module

logical. Whether to include the 'clade_annotation' module (annotate_ui/server)

See ?modules for details about the modules.

Examples

# working with `phylo` objects if (interactive()) { library(ape) data(bird.orders) make_phynotate(phylogeny=bird.orders, modules = "LPBT") } # working with `tbl_tree` or `treedata` objects if (interactive()) { library(ape) data(bird.orders) library(tidytree) library(dplyr) tidytree::as_tibble(bird.orders) %>% dplyr::mutate(trait = runif(n = nrow(.), min = 0, max = 5)) %>% phynotate::make_phynotate(phylogeny = .) }