make_phynotate.Rdmake_phynotate generates a standalone {shiny} app with one phylogeny and
widgets for customizing its appearence. This is a wrapper around
phynotate::main_ui/server to simplify usage when a the main module is
called as a standalone app. See ?draw_server and ?main_server for an
for info on how to include the modules in an existing app.
make_phynotate( phylogeny = NULL, draw_modules = "LPTB", annotation_module = FALSE )
| phylogeny | an object of class |
|---|---|
| draw_modules | character string specifying the customizing widgets (shiny modules) to
include. The default is |
| annotation_module | logical. Whether to include the 'clade_annotation' module ( See |
# working with `phylo` objects if (interactive()) { library(ape) data(bird.orders) make_phynotate(phylogeny=bird.orders, modules = "LPBT") } # working with `tbl_tree` or `treedata` objects if (interactive()) { library(ape) data(bird.orders) library(tidytree) library(dplyr) tidytree::as_tibble(bird.orders) %>% dplyr::mutate(trait = runif(n = nrow(.), min = 0, max = 5)) %>% phynotate::make_phynotate(phylogeny = .) }